domain Package
==============


:mod:`domain` Package
---------------------

.. automodule:: stoqlib.domain
    :members:
    :show-inheritance:

:mod:`account`
--------------

.. automodule:: stoqlib.domain.account
    :members:
    :show-inheritance:

:mod:`address`
--------------

.. automodule:: stoqlib.domain.address
    :members:
    :show-inheritance:

:mod:`attachment`
-----------------

.. automodule:: stoqlib.domain.attachment
    :members:
    :show-inheritance:

:mod:`base`
-----------

.. automodule:: stoqlib.domain.base
    :members:
    :show-inheritance:

:mod:`commission`
-----------------

.. automodule:: stoqlib.domain.commission
    :members:
    :show-inheritance:

:mod:`costcenter`
-----------------

.. automodule:: stoqlib.domain.costcenter
    :members:
    :show-inheritance:

:mod:`devices`
--------------

.. automodule:: stoqlib.domain.devices
    :members:
    :show-inheritance:

:mod:`event`
------------

.. automodule:: stoqlib.domain.event
    :members:
    :show-inheritance:

:mod:`events`
-------------

.. automodule:: stoqlib.domain.events
    :members:
    :show-inheritance:

:mod:`exampledata`
------------------

.. automodule:: stoqlib.domain.exampledata
    :members:
    :show-inheritance:

:mod:`fiscal`
-------------

.. automodule:: stoqlib.domain.fiscal
    :members:
    :show-inheritance:

:mod:`image`
------------

.. automodule:: stoqlib.domain.image
    :members:
    :show-inheritance:
    :exclude-members: on_create on_delete on_update

:mod:`interfaces`
-----------------

.. automodule:: stoqlib.domain.interfaces
    :members:
    :show-inheritance:

:mod:`inventory`
----------------

.. automodule:: stoqlib.domain.inventory
    :members:
    :show-inheritance:

:mod:`invoice`
--------------

.. automodule:: stoqlib.domain.invoice
    :members:
    :show-inheritance:

:mod:`loan`
-----------

.. automodule:: stoqlib.domain.loan
    :members:
    :show-inheritance:

:mod:`parameter`
----------------

.. automodule:: stoqlib.domain.parameter
    :members:
    :show-inheritance:

:mod:`payment.card`
-----------------------

.. automodule:: stoqlib.domain.payment.card
    :members:
    :show-inheritance:

:mod:`payment.category`
-----------------------

.. automodule:: stoqlib.domain.payment.category
    :members:
    :show-inheritance:

:mod:`payment.comment`
----------------------

.. automodule:: stoqlib.domain.payment.comment
    :members:
    :show-inheritance:

:mod:`payment.dailymovement`
----------------------------

.. automodule:: stoqlib.domain.payment.dailymovement
    :members:
    :show-inheritance:

:mod:`payment.group`
--------------------

.. automodule:: stoqlib.domain.payment.group
    :members:
    :show-inheritance:

:mod:`payment.method`
---------------------

.. automodule:: stoqlib.domain.payment.method
    :members:
    :show-inheritance:

:mod:`payment.operation`
------------------------

.. automodule:: stoqlib.domain.payment.operation
    :members:
    :show-inheritance:

:mod:`payment.payment`
----------------------

.. automodule:: stoqlib.domain.payment.payment
    :members:
    :show-inheritance:

:mod:`payment.renegotiation`
----------------------------

.. automodule:: stoqlib.domain.payment.renegotiation
    :members:
    :show-inheritance:

:mod:`payment.views`
--------------------

.. automodule:: stoqlib.domain.payment.views
    :members:
    :show-inheritance:


:mod:`person`
-------------

.. automodule:: stoqlib.domain.person
    :members:
    :show-inheritance:
    :exclude-members: on_create on_delete on_update

:mod:`plugin`
-------------

.. automodule:: stoqlib.domain.plugin
    :members:
    :show-inheritance:

:mod:`product`
--------------

.. automodule:: stoqlib.domain.product
    :members:
    :show-inheritance:
    :exclude-members: on_create on_delete on_update

:mod:`production`
-----------------

.. automodule:: stoqlib.domain.production
    :members:
    :show-inheritance:

:mod:`profile`
--------------

.. automodule:: stoqlib.domain.profile
    :members:
    :show-inheritance:

:mod:`purchase`
---------------

.. automodule:: stoqlib.domain.purchase
    :members:
    :show-inheritance:

:mod:`receiving`
----------------

.. automodule:: stoqlib.domain.receiving
    :members:
    :show-inheritance:

:mod:`returnedsale`
-------------------

.. automodule:: stoqlib.domain.returnedsale
    :members:
    :show-inheritance:

:mod:`sale`
-----------

.. automodule:: stoqlib.domain.sale
    :members:
    :show-inheritance:

:mod:`sellable`
---------------

.. automodule:: stoqlib.domain.sellable
    :members:
    :show-inheritance:
    :exclude-members: on_create on_delete on_update

:mod:`service`
--------------

.. automodule:: stoqlib.domain.service
    :members:
    :show-inheritance:
    :exclude-members: on_create on_delete on_update

:mod:`station`
--------------

.. automodule:: stoqlib.domain.station
    :members:
    :show-inheritance:
    :exclude-members: on_create on_delete on_update

:mod:`stockdecrease`
--------------------

.. automodule:: stoqlib.domain.stockdecrease
    :members:
    :show-inheritance:

:mod:`synchronization`
----------------------

.. automodule:: stoqlib.domain.synchronization
    :members:
    :show-inheritance:

:mod:`system`
-------------

.. automodule:: stoqlib.domain.system
    :members:
    :show-inheritance:

:mod:`taxes`
------------

.. automodule:: stoqlib.domain.taxes
    :members:
    :show-inheritance:

:mod:`till`
-----------

.. automodule:: stoqlib.domain.till
    :members:
    :show-inheritance:

:mod:`transfer`
---------------

.. automodule:: stoqlib.domain.transfer
    :members:
    :show-inheritance:

:mod:`uiform`
-------------

.. automodule:: stoqlib.domain.uiform
    :members:
    :show-inheritance:

:mod:`views`
------------

.. automodule:: stoqlib.domain.views
    :members:
    :show-inheritance:

:mod:`workorder`
----------------

.. automodule:: stoqlib.domain.workorder
    :members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoqlib.domain.test

